@@ -19,3 +19,10 @@ from .app import start_client as start_client
 from .app import start_keras_client as start_keras_client
 from .client import Client as Client
 from .keras_client import KerasClient as KerasClient
+
+__all__ = [
+    "start_client",
+    "start_keras_client",
+    "Client",
+    "KerasClient",
+]
