@@ -40,6 +40,11 @@ EvaluateResultsAndFailures = Tuple[
 ]
 
 
+def set_strategy(strategy: Optional[Strategy]) -> Strategy:
+    """Return Strategy."""
+    return strategy if strategy is not None else DefaultStrategy()
+
+
 class Server:
     """Flower server."""
 
@@ -48,13 +53,13 @@ class Server:
     ) -> None:
         self._client_manager: ClientManager = client_manager
         self.weights: Weights = []
-        self.strategy: Strategy = strategy if strategy is not None else DefaultStrategy()
+        self.strategy: Strategy = set_strategy(strategy)
 
     def client_manager(self) -> ClientManager:
         """Return ClientManager."""
         return self._client_manager
 
-    # pylint: disable-msg=too-many-locals
+    # pylint: disable=too-many-locals
     def fit(self, num_rounds: int) -> History:
         """Run federated averaging for a number of rounds."""
         history = History()
@@ -63,7 +68,10 @@ class Server:
         res = self.strategy.evaluate(weights=self.weights)
         if res is not None:
             log(
-                INFO, "initial weights (loss/accuracy): %s, %s", res[0], res[1],
+                INFO,
+                "initial weights (loss/accuracy): %s, %s",
+                res[0],
+                res[1],
             )
             history.add_loss_centralized(rnd=0, loss=res[0])
             history.add_accuracy_centralized(rnd=0, acc=res[1])
@@ -125,7 +133,9 @@ class Server:
             log(INFO, "evaluate: no clients sampled, cancel federated evaluation")
             return None
         log(
-            DEBUG, "evaluate: strategy sampled %s clients", len(client_instructions),
+            DEBUG,
+            "evaluate: strategy sampled %s clients",
+            len(client_instructions),
         )
 
         # Evaluate current global weights on those clients
@@ -148,7 +158,10 @@ class Server:
             rnd=rnd, weights=self.weights, client_manager=self._client_manager
         )
         log(
-            DEBUG, "fit_round: strategy sampled %s clients", len(client_instructions),
+            DEBUG,
+            "fit_round: strategy sampled %s clients (out of %s)",
+            len(client_instructions),
+            self._client_manager.num_available(),
         )
         if not client_instructions:
             log(INFO, "fit_round: no clients sampled, cancel fit")
