@@ -45,7 +45,7 @@ class FedFSv0(FedAvg):
     """Strategy implementation which alternates between fast and slow
     rounds."""
 
-    # pylint: disable-msg=too-many-arguments,too-many-instance-attributes,too-many-locals
+    # pylint: disable=too-many-arguments,too-many-instance-attributes,too-many-locals
     def __init__(
         self,
         fraction_fit: float = 0.1,
@@ -82,11 +82,11 @@ class FedFSv0(FedAvg):
         self.contributions: Dict[str, List[Tuple[int, int, int]]] = {}
 
     def __repr__(self) -> str:
-        # pylint: disable-msg=line-too-long
-        rep = f"FedFSv0(r_fast={self.r_fast}, r_slow={self.r_slow}, t_fast={self.t_fast}, t_slow={self.t_slow})"
+        rep = f"FedFSv0(r_fast={self.r_fast}, r_slow={self.r_slow}, "
+        rep += f"t_fast={self.t_fast}, t_slow={self.t_slow})"
         return rep
 
-    # pylint: disable-msg=too-many-locals
+    # pylint: disable=too-many-locals
     def on_configure_fit(
         self, rnd: int, weights: Weights, client_manager: ClientManager
     ) -> List[Tuple[ClientProxy, FitIns]]:
@@ -145,9 +145,10 @@ class FedFSv0(FedAvg):
                 contribs: List[Tuple[int, int, int]] = self.contributions[cid]
                 penalty = statistics.mean([c / m for _, c, m in contribs])
             # `p` should be:
-            #   - High for clients which have never been picked before
-            #   - Medium for clients which have contributed, but not used their entire budget
-            #   - Low (but not 0) for clients which have been picked and used their budget
+            # - High for clients which have never been picked before
+            # - Medium for clients which have contributed,
+            #   but not used their entire budget
+            # - Low (but not 0) for clients which have been picked and used their budget
             raw.append(1.1 - penalty)
 
         # Sample clients
