@@ -59,7 +59,9 @@ def main() -> None:
         help="Minimum number of available clients required for sampling (default: 1)",
     )
     parser.add_argument(
-        "--log_host", type=str, help="Logserver address (no default)",
+        "--log_host",
+        type=str,
+        help="Logserver address (no default)",
     )
     args = parser.parse_args()
 
@@ -82,7 +84,9 @@ def main() -> None:
 
     # Run server
     fl.server.start_server(
-        args.server_address, server, config={"num_rounds": args.rounds},
+        args.server_address,
+        server,
+        config={"num_rounds": args.rounds},
     )
 
 
